// =========================================
// = Copyright (C)  Guido Walter Pettinari =
// =========================================
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; If not, see <http://www.gnu.org/licenses/>.

#include <octave/oct.h>
#include "gaussian_pdfcdf.h"

// ============================
// = Original Native Function =
// ============================
void gaussian_cdf (
   double *cdf,
   const double *x,
   int numel_x,
   double mean,
   double sigma
   );
   
DEFUN_DLD (
   gaussian_cdf,
   args,
   ,
   "PROTOTYPE:\n\
   gaussian_cdf ( x, mean, sigma )\n\
   \n\
   PURPOSE:\n\
   Compute the Cumulative Distribution Function of the Normal\n\
   distribution.\n\
   This function is a wrapper to 'gsl_cdf_gaussian_P' from\n\
   the GNU scientific library.\n\
   \n\
   INPUT:\n\
   x: a matrix with the random variable values\n\
   mean: the mean of the distribution\n\
   sigma: the standard deviation of the distribution\n\
   "
   ) {

// Number of input arguments
int nargin = args.length();

if ( nargin < 1 ) {
   print_usage();
   return octave_value_list();
}

// =========
// = Input =
// =========
Matrix x( args(0).matrix_value() );

double mean = 0.0;
if ( nargin > 1 )
   mean = args(1).double_value();

double sigma = 1.0;
if ( nargin > 2 )
   sigma = args(2).double_value();

int numel_x = x.nelem();
dim_vector dim_x = x.dims();

// ==========
// = Output =
// ==========
Matrix cdf(dim_x);

// ===============
// = Calculation =
// ===============
// Get pointers from input & output
double *cdf_ = (double*)cdf.data();
const double *x_ = (const double*)x.data();

// Perform the actual computation
gaussian_cdf (
   cdf_,
   x_,
   numel_x,
   mean,
   sigma
   );

return octave_value(cdf);

}
